Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1909)

Unified Diff: chrome/browser/tab_contents/tab_contents.cc

Issue 660137: Allow users to close the find session and activate the current link via ctrl-... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 10 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/tab_contents/tab_contents.h ('k') | chrome/browser/views/find_bar_host.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/tab_contents/tab_contents.cc
===================================================================
--- chrome/browser/tab_contents/tab_contents.cc (revision 41087)
+++ chrome/browser/tab_contents/tab_contents.cc (working copy)
@@ -1135,16 +1135,17 @@
find_next);
}
-void TabContents::StopFinding(bool clear_selection) {
- // When |clear_selection| is true, it means the find string has been cleared
+void TabContents::StopFinding(
+ FindBarController::SelectionAction selection_action) {
+ // When the action is kClearAction, it means the find string has been cleared
// by the user, but the UI has not been dismissed.
- if (!clear_selection)
+ if (selection_action != FindBarController::kClearSelection)
find_ui_active_ = false;
previous_find_text_ = find_text_;
find_text_.clear();
find_op_aborted_ = true;
last_search_result_ = FindNotificationDetails();
- render_view_host()->StopFinding(clear_selection);
+ render_view_host()->StopFinding(selection_action);
}
void TabContents::OnSavePage() {
« no previous file with comments | « chrome/browser/tab_contents/tab_contents.h ('k') | chrome/browser/views/find_bar_host.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698